<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Niveau %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Geen Cover</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Nieuwe extensie:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Nieuwe extensie maken</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>Map voor videobestanden</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>Deze map moet bestaan en de gebruiker moet enkel leesbevoegdheid voor deze map hebben.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>Startniveau &apos;Parental Control&apos;</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 -Hoogste</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - Laagste</translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation>Dit is het niveau waarin MythVideo start. Alle films met een gelijk of lager niveau worden standaard getoond. De &apos;Parental Control&apos; PIN kan best zo ingesteld worden dat het niveau zo weinig mogelijk veranderd moet worden.</translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>&apos;Parental Control&apos; PIN</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation>Indien ingesteld is het niet meer mogelijk naar dit scherm terug te keren om de PIN te resetten zonder de bestaande PIN in te voeren. U bent gewaarschuwd!</translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>Onbekende bestandstypes tonen</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation>Indien geselecteerd worden alle bestanden in de MythVideo-map getoond tenzij de extensie expliciet ingesteld werd op negeren.</translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation>Filmlijst bladert bestanden</translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Indien geselecteerd worden alle relevante bestanden in de MythVideo-map getoond. Gescand of niet.</translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>Instellingen voor het afspeelprogramma</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">&apos;Parental PIN&apos;:</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Geen cover</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation type="obsolete">Onbekende beoordeling</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Standaard afspeelprogramma</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation>Nieuw gescande bestanden worden standaard getoond</translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation>Indien geselecteerd worden nieuw gescande bestanden in de Video Manager gemarkeerd als &quot;bladerbaar&quot;.</translation>
    </message>
    <message>
        <source>New category</source>
        <translation>Nieuwe categorie</translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation>Deze PIN wordt gebruikt om het huidige &apos;Parental Control&apos; niveau te controleren. Als U dit wil instellen is het handig om enkel numerieke invoer te gebruiken.</translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation>Commando om te zoeken naar filminfo</translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation>Dit commando moet uitgevoerd kunnen worden door de huidige gebruiker.</translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation>Commando om te zoeken naar filmcovers</translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation>Commando om filmdata te extraheren</translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation>Map voor filmcovers</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation>Deze map moet bestaan en de gebruiker moet lees- en schrijfbevoegdheid hebben.</translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation>Video Manager</translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation>Kan cover niet downloaden</translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation>Er bestaat een cover voor deze film maar die kan momenteel niet gedownload worden.

</translation>
    </message>
    <message>
        <source>Default View</source>
        <translation>Standaard uiterlijk</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Gallerij</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Browser</translation>
    </message>
    <message>
        <source>Listings</source>
        <translation>Lijst</translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation>Agressieve &apos;Parental Control&apos;</translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation>Dit commando wordt gebruikt voor elk bestand met een niet gedefinieerde extensie. U kan ook de naam van een van de afspeel-plugins (bv. &apos;Internal&apos;) invoeren.</translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation>Getoond aantal rijen</translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation>Getoond aantal kolommen</translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation>Toon titel onder thumbnail</translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation>Indien geselecteerd zal de tekst de thumbnail kleiner maken.</translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation>Verhouding van de thumbnails behouden</translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation>Indien geselecteerd zal de verhouding van de thumbnails behouden worden. Zo niet worden ze geschaald tot de afmeting van het achtergrondicoon.</translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation>Video Gallerij</translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation>Het standaard uiterlijk van MythVideo. Andere zijn mogelijk via het popup-menu (MENU),</translation>
    </message>
    <message>
        <source>Video Browser browses files</source>
        <translation>Video Browser bladert bestanden</translation>
    </message>
    <message>
        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Als dit is ingeschakeld, zal het Video Blader scherm alle relevante bestanden in de MythVideo map laten zien, zelfs als ze niet gescanned zijn.</translation>
    </message>
    <message>
        <source>Video Gallery browses files</source>
        <translation>Video Gallerij bladert in bestanden</translation>
    </message>
    <message>
        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Als dit is ingeschakeld, zal het Video Gallerij scherm alle relevante bestanden in de MythVideo map laten zien, zelfs als ze niet gescanned zijn.</translation>
    </message>
    <message>
        <source>General Settings (1/2)</source>
        <translation>Globale Instellingen (1/2)</translation>
    </message>
    <message>
        <source>General Settings (2/2)</source>
        <translation>Globale Instellingen (2/2)</translation>
    </message>
    <message>
        <source>Video List Loads Video Meta Data</source>
        <translation>Video Lijst Laadt Video Meta Data</translation>
    </message>
    <message>
        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
        <translation>Als dit is ingeschakeld samen met Blader Bestanden, zal de Video Lijst bekende metadata uit de database halen. Dit uitschakelen kan het maken van de Video Lijst enorm versnellen.</translation>
    </message>
    <message>
        <source>Sorting ignores case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, case is ignored when sorting entries in a view.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show folders for database views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, sub folders of your video directory will be shown in supported views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image cache size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting determines the number of images MythVideo will cache for views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>^(The |A |An )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Alle</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Neen</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished">Jaar</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation type="unfinished">Gebruikersbeoordeling</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation type="unfinished">Speeltijd</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Regisseur:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Jaar:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Beoordeling:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>&apos;Parental Control&apos; Niveau:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>Komt in lijst:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Speelduur:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Inhoud:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Bestandsnaam:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Cover bestand:</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>IMDBnr.:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>downloaden van gegevens ...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ zoeken naar ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>Geef IMDBnr.</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>bezig met inlezen ...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>Geen films gevonden</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Regie</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Bestand:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Afspeelprogramma:</translation>
    </message>
    <message>
        <source>PL </source>
        <translation>PL</translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>Bestandstype koppelingen</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Extensie:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Commando:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Gebruik standaard afspeelprogramma:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Negeer:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Bewerk video gegevens:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>&apos;Parental Control&apos;:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>Bestand dat hierna dient afgespeeld:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>Weergeven in lijst:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Cover:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Uniek afspeelcommando:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/path/naar/afbeelding.jpg</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categorie:</translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation>Filter op filmoverzicht</translation>
    </message>
    <message>
        <source>Category :</source>
        <translation>Categorie :</translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation>Genre :</translation>
    </message>
    <message>
        <source>Country :</source>
        <translation>Land :</translation>
    </message>
    <message>
        <source>Year :</source>
        <translation>Jaar :</translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation>Speeltijd :</translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation>Gebruikersbeoordeling :</translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation>Bladeren :</translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation>Sorteren op :</translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation>Geen video</translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation>SELECTEER: Bewerk</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation>&apos;Parental Control&apos;</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Jaar</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation>Speeltijd</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation>Gebruikersbeoordeling</translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation>INFO - Actie Menu</translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation>Omhoog/Omlaag, Pagina Op/Neer: Blader  MENU: Opties INFO: Actie Menu</translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation>Speel vervolgens dit bestand:</translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 van %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>Geen Films</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Geen beoordeling beschikbaar.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minuten</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Bekijk deze Film</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Beschrijving Inhoud</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filter weergave</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation>Browsermodus</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Gallerijmodus</translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation>Lijstmodus</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Kies actie</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Ouderlijk toezicht Pincode:</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation>Resultaat van deze filer : %1 video(s)</translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation>Resultaat van deze filer : Geen videos</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Onbekend</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuten</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="obsolete">Alle</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Bewaar als standaard</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation>Gebruik Filterweergave</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Bekijk deze video</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Beschrijving Inhoud</translation>
    </message>
    <message>
        <source>View Details</source>
        <translation>Bekijk Details</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minuten</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Neen</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Geen Cover</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Onbekend</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Geen</translation>
    </message>
    <message>
        <source>NR</source>
        <translation type="obsolete">Niet Beoordeeld</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation>wissen mislukt</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>Kies bewerking:</translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation>Bewerk filmgegevens</translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation>Zoek IMDB</translation>
    </message>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation>Geef handmatig IMDBnr.</translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation>Wis gegevens</translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation>In lijst ja/neen</translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation>Wis Film</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filter Weergave</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation>Dit bestand wissen?</translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Geen beoordeling beschikbaar.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minuten</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">&apos;Parental Control&apos; PIN:</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Kies Actie</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Bekijk Film</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Beschrijving Inhoud</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filter Weergave</translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation>Ga naar Browsermodus</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Ga naar Gallerijmodus</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
</TS>
